# 20220518_allsky_dec2276_tuned

- DL1ab processing from `20220511_allsky_std` production from dec_2276 
- workflow stages:
    - dl1ab
    - merge_dl1
    - train_pipe
    - dl1_to_dl2
    - dl2_to_irfs

- lstchain config provided by Abelardo

- paths: `/fefs/aswg/data/mc/{data_level}/AllSky/20220518_allsky_dec2276_tuned/{train_test}/dec_2276/`